@@ -11,5 +11,6 @@
 # WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the
 # License for the specific language governing permissions and limitations
 # under the License.
-from supertokens_python.framework.django.django_middleware import \
-    middleware  # type: ignore
+from supertokens_python.framework.django.django_middleware import (
+    middleware,  # type: ignore
+)
