@@ -22,15 +22,18 @@ from supertokens_python.supertokens import Supertokens
 from supertokens_python.utils import humanize_time
 
 if TYPE_CHECKING:
-    from supertokens_python.recipe.passwordless.types import \
-        PasswordlessLoginSMSTemplateVars
+    from supertokens_python.recipe.passwordless.types import (
+        PasswordlessLoginSMSTemplateVars,
+    )
 
 
 def pless_sms_content(input_: PasswordlessLoginSMSTemplateVars) -> SMSContent:
     supertokens = Supertokens.get_instance()
     app_name = supertokens.app_info.app_name
     code_lifetime = humanize_time(input_.code_life_time)
-    body = get_pless_sms_body(app_name, code_lifetime, input_.url_with_link_code, input_.user_input_code)
+    body = get_pless_sms_body(
+        app_name, code_lifetime, input_.url_with_link_code, input_.user_input_code
+    )
     return SMSContent(body, input_.phone_number)
 
 
@@ -38,25 +41,31 @@ def get_pless_sms_body(
     app_name: str,
     code_lifetime: str,
     url_with_link_code: Union[str, None] = None,
-    user_input_code: Union[str, None] = None
+    user_input_code: Union[str, None] = None,
 ) -> str:
     if (url_with_link_code is not None) and (user_input_code is not None):
-        sms_template = dedent("""\
+        sms_template = dedent(
+            """\
         OTP to login is ${otp} for ${appname}
 
         Or click ${magicLink} to login.
 
-        This is valid for ${time}.""")
+        This is valid for ${time}."""
+        )
     elif url_with_link_code is not None:
-        sms_template = dedent("""\
+        sms_template = dedent(
+            """\
         Click ${magicLink} to login to ${appname}
 
-        This is valid for ${time}.""")
+        This is valid for ${time}."""
+        )
     elif user_input_code is not None:
-        sms_template = dedent("""\
+        sms_template = dedent(
+            """\
         OTP to login is ${otp} for ${appname}
 
-        This is valid for ${time}.""")
+        This is valid for ${time}."""
+        )
     else:
         raise Exception("This should never be thrown.")
 
