@@ -18,6 +18,7 @@ from urllib.parse import urlencode
 
 from httpx import AsyncClient
 from supertokens_python.exceptions import raise_general_exception
+from supertokens_python.recipe.emailverification import EmailVerificationRecipe
 from supertokens_python.recipe.emailverification.interfaces import (
     CreateEmailVerificationTokenOkResult,
 )
@@ -158,21 +159,23 @@ class APIImplementation(APIInterface):
             return SignInUpPostNoEmailGivenByProviderResponse()
 
         signinup_response = await api_options.recipe_implementation.sign_in_up(
-            provider.id, user_info.user_id, email, email_verified, user_context
+            provider.id, user_info.user_id, email, user_context
         )
 
         if email_verified:
-            token_response = await api_options.email_verification_recipe_implementation.create_email_verification_token(
-                user_id=signinup_response.user.user_id,
-                email=signinup_response.user.email,
-                user_context=user_context,
-            )
-
-            if isinstance(token_response, CreateEmailVerificationTokenOkResult):
-                await api_options.email_verification_recipe_implementation.verify_email_using_token(
-                    token=token_response.token, user_context=user_context
+            ev_instance = EmailVerificationRecipe.get_instance_optional()
+            if ev_instance is not None:
+                token_response = await ev_instance.recipe_implementation.create_email_verification_token(
+                    user_id=signinup_response.user.user_id,
+                    email=signinup_response.user.email,
+                    user_context=user_context,
                 )
 
+                if isinstance(token_response, CreateEmailVerificationTokenOkResult):
+                    await ev_instance.recipe_implementation.verify_email_using_token(
+                        token=token_response.token, user_context=user_context
+                    )
+
         user = signinup_response.user
         session = await create_new_session(
             api_options.request, user.user_id, user_context=user_context
