@@ -14,12 +14,13 @@
 
 from typing import Any, Awaitable, Callable, Dict, Union
 
-from supertokens_python.ingredients.smsdelivery.types import \
-    SMSDeliveryInterface
-from supertokens_python.recipe.passwordless.smsdelivery.services.backward_compatibility import \
-    BackwardCompatibilityService as PlessBackwardCompatibilityService
-from supertokens_python.recipe.passwordless.types import \
-    PasswordlessLoginSMSTemplateVars
+from supertokens_python.ingredients.smsdelivery.types import SMSDeliveryInterface
+from supertokens_python.recipe.passwordless.smsdelivery.services.backward_compatibility import (
+    BackwardCompatibilityService as PlessBackwardCompatibilityService,
+)
+from supertokens_python.recipe.passwordless.types import (
+    PasswordlessLoginSMSTemplateVars,
+)
 from supertokens_python.supertokens import AppInfo
 
 from ....types import SMSTemplateVars
@@ -28,12 +29,23 @@ from ....types import SMSTemplateVars
 class BackwardCompatibilityService(SMSDeliveryInterface[SMSTemplateVars]):
     pless_backward_compatibility_service: PlessBackwardCompatibilityService
 
-    def __init__(self, app_info: AppInfo,
-                 pless_create_and_send_custom_text_message: Union[Callable[[PasswordlessLoginSMSTemplateVars, Dict[str, Any]], Awaitable[None]], None] = None
-                 ) -> None:
+    def __init__(
+        self,
+        app_info: AppInfo,
+        pless_create_and_send_custom_text_message: Union[
+            Callable[
+                [PasswordlessLoginSMSTemplateVars, Dict[str, Any]], Awaitable[None]
+            ],
+            None,
+        ] = None,
+    ) -> None:
         self.pless_backward_compatibility_service = PlessBackwardCompatibilityService(
             app_info, pless_create_and_send_custom_text_message
         )
 
-    async def send_sms(self, template_vars: SMSTemplateVars, user_context: Dict[str, Any]) -> None:
-        await self.pless_backward_compatibility_service.send_sms(template_vars, user_context)
+    async def send_sms(
+        self, template_vars: SMSTemplateVars, user_context: Dict[str, Any]
+    ) -> None:
+        await self.pless_backward_compatibility_service.send_sms(
+            template_vars, user_context
+        )
